@@ -6,7 +6,7 @@ Headers, Request and FieldStorage classes, which is used for managing requests.
 from wsgiref.headers import Headers as WHeaders
 from cgi import FieldStorage as CgiFieldStorage
 from time import strftime, gmtime
-from sys import version_info, stderr
+from sys import version_info, version, stderr
 from inspect import stack
 
 import os, re
@@ -414,9 +414,8 @@ class Request(object):
         """
         return self.__poor_environ.get(
                 'poor_SecretKey',
-                'Poor WSGI/%s for Python/%s.%s on %s' % \
-                    (__version__, version_info[0], version_info[1],
-                    self.server_software))
+                '%s%s%s%s%s' % (__version__, self.server_software, version,
+                                os.getcwd(), ''.join(str(x) for x in os.uname()) ))
 
     @property
     def document_index(self):
@@ -532,8 +531,9 @@ class Request(object):
         """
         options = {}
         for key,val in self.__poor_environ.items():
+            key = key.strip()
             if key[:4].lower() == 'app_':
-                options[key[4:].lower()] = val
+                options[key[4:].lower()] = val.strip()
         return options
 
     def get_remote_host(self):
@@ -662,10 +662,10 @@ class EmptyForm(dict):
     to Off.
     """
     def getvalue(self, name, default = None):
-        return None
+        return default
 
     def getfirst(self, name, default = None, fce = uni):
-        return None
+        return fce(default) if not default is None else default
 
     def getlist(self, name, fce = uni):
         return []
